Index - Criterion.rs

## Criterion.rs Benchmark Index

See individual benchmark pages below for more details.

- INSERT

- aiomysql
- asyncmy
- mysqlclient
- pymysql
- pyro-async
- pyro-sync

- SELECT 1

- aiomysql
- asyncmy
- mysqlclient
- pymysql
- pyro-async
- pyro-sync

- SELECT 10

- aiomysql
- asyncmy
- mysqlclient
- pymysql
- pyro-async
- pyro-sync

- SELECT 100

- aiomysql
- asyncmy
- mysqlclient
- pymysql
- pyro-async
- pyro-sync

- TX_INSERT

- aiomysql
- asyncmy
- mysqlclient
- pymysql
- pyro-async
- pyro-sync